==> SyL-0.15.1.tar.gz: SyL/include/framework/Logger/SyL_LoggerFile.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerFile.php,v 1.18 2008/01/15 09:19:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륯饹
 */
require_once SYL_INCLUDE_DIR . '/lib/SyL_File.php';

/**
 * եؤΥϥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerFile.php,v 1.18 2008/01/15 09:19:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_LoggerFile extends SyL_Logger
{
    /**
     * SyL_File֥
     * 
     * @access public
     */
    var $appender = null;

    /**
     * ץ
     *
     * @access public
     * @param string ե̾
     */
    function open($filename)
    {
        // ե̾Ѵ
        $filename = str_replace('YYYY', date('Y'), $filename);
        $filename = str_replace('MM',   date('m'), $filename);
        $filename = str_replace('DD',   date('d'), $filename);

        if ($this->appender == null) {
            $this->appender =& SyL_File::factory('a', $filename);
            $this->appender->setPermission(0666);
            $this->appender->open();
        }
    }

    /**
     * ν
     *
     * @access public
     * @param string ٥̾
     * @param string å
     */
    function log($level, $message)
    {
        if ($level != '') {
            $message = sprintf('%s [%s:%s] {%s} %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->getLoggingClass(), rtrim($message));
        }
        if ($this->immediate || ($level == '')) {
            $this->appender->write($message . $this->eol);
        } else {
            $this->buffer[] = $message;
        }
    }

    /**
     * եĤ
     *
     * @access public
     */
    function close()
    {
        if ($this->appender != null) {
            parent::close();
            $this->appender->close();
            $this->appender = null;
        }
    }
}

?>

==> SyL-0.15.3.tar.gz: SyL/include/framework/Logger/SyL_LoggerFile.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerFile.php,v 1.19 2008/08/31 13:58:49 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륯饹
 */
require_once SYL_INCLUDE_DIR . '/lib/SyL_File.php';

/**
 * եؤΥϥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerFile.php,v 1.19 2008/08/31 13:58:49 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_LoggerFile extends SyL_Logger
{
    /**
     * SyL_File֥
     * 
     * @access public
     */
    var $appender = null;

    /**
     * ץ
     *
     * @access public
     * @param string ե̾
     */
    function open($filename)
    {
        // ե̾Ѵ
        $search   = array('{YYYY}', '{MM}', '{DD}');
        $replace  = explode('-', date('Y-m-d'));
        $filename = str_replace($search, $replace, $filename);

        if ($this->appender == null) {
            $this->appender =& SyL_File::factory('a', $filename);
            $this->appender->setPermission(0666);
            $this->appender->open();
        }
    }

    /**
     * ν
     *
     * @access public
     * @param string ٥̾
     * @param string å
     */
    function log($level, $message)
    {
        if ($level != '') {
            $message = sprintf('%s [%s:%s] {%s} %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->getLoggingClass(), rtrim($message));
        }
        if ($this->immediate || ($level == '')) {
            $this->appender->write($message . $this->eol);
        } else {
            $this->buffer[] = $message;
        }
    }

    /**
     * եĤ
     *
     * @access public
     */
    function close()
    {
        if ($this->appender != null) {
            parent::close();
            $this->appender->close();
            $this->appender = null;
        }
    }
}

?>
